@@ -4,7 +4,7 @@ use strictures 2;
 
 ## no critic (ProhibitExcessComplexity)
 
-our $VERSION = "4.102";
+our $VERSION = "4.103";
 
 =head1 NAME
 
@@ -65,7 +65,8 @@ sub _options_prepare_descriptive {
 
         push @{ $all_options{$name} }, $name;
         if ( $data{short} ) {
-            my @shrt_list = split( "|", $data{short} );
+            ## no critic (RegularExpressions::RequireExtendedFormatting)
+            my @shrt_list = split( m/\|/, $data{short} );
             foreach my $shrt (@shrt_list) {
                 croak
                     "There is already an option '$shrt' - can't use it to shorten '$name'"
